@@ -6,7 +6,7 @@ def get_input(event):
         trigger_source = None
         input_params = None
 
-        if 'httpMethod' in event:
+        if 'httpMethod' in event and event['httpMethod'] == 'POST':
             trigger_source = 'api-gateway'
             if 'body' in event:
                 input_params = json.loads(event['body'])
@@ -22,9 +22,6 @@ def get_input(event):
         else:
             raise Exception("Input is not valid.")
 
-        return {
-            'statusCode': 200,
-            'body': {'data': input_params, 'source': trigger_source}
-        }
+        return { 'input': input_params, 'source': trigger_source }
     except Exception as e:
         raise Exception(e)
\ No newline at end of file
